@@ -1,7 +1,7 @@
 drop table BPEL_ACTIVITY_INST cascade constraints;
 drop table BPEL_BASE_ACTIVITY_DEF cascade constraints;
 drop table BPEL_FAULT_ cascade constraints;
-drop table BPEL_FAULT_MSG_PART cascade constraints;
+drop table BPEL_REC cascade constraints;
 drop table COPY_FULL_IMPL cascade constraints;
 drop table CORR_DEF_ cascade constraints;
 drop table CS_INIT_FULL_IMPL cascade constraints;
@@ -10,7 +10,6 @@ drop table FRM_PRT_DEF_ cascade constraints;
 drop table FROM_TO_FULL cascade constraints;
 drop table NOVA_CS_INST_PROP cascade constraints;
 drop table NOVA_NAMESPACE cascade constraints;
-drop table NOVA_VAR_MSG_PART2 cascade constraints;
 drop table ON_ALRM_DEF_ cascade constraints;
 drop table ON_EVT_DEF_ cascade constraints;
 drop table ON_MSG_DEF_ cascade constraints;
